import {Component, inject} from '@angular/core';
import {FormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import QualificationService from "../services/qualification.service";
import {MatDialogRef} from "@angular/material/dialog";

@Component({
    selector: 'app-create-qualification',
    imports: [
        ReactiveFormsModule
    ],
    templateUrl: './create-qualification.component.html',
    styleUrl: './create-qualification.component.css'
})
export class CreateQualificationComponent {
    private formBuilder: FormBuilder = inject(FormBuilder);
    private qualificationService: QualificationService = inject(QualificationService);
    private dialogRef: MatDialogRef<CreateQualificationComponent> = inject(MatDialogRef);

    qualificationForm = this.formBuilder.group({
        'skill': ['', Validators.required],
    });

    create() {
        if (!this.qualificationForm.valid) {
            console.error('Validation failed');
            return;
        }

        this.qualificationService.create(this.qualificationForm.value).subscribe({
            next: (createdQualification) => {
                this.dialogRef.close(createdQualification);
            },
            error: (error) => {
                console.error('Error creating qualification:', error);
            }
        });
    }
}
